class Maze:
    UP = '1'
    RIGHT = '2'
    DOWN = '3'
    LEFT = '4'
    EXIT = '5'

    def __init__(self):
        self.game_map = [
            ['Y', '#', '#', '#'],
            [' ', '#', '#', '#'],
            [' ', '#', '#', '#'],
            [' ', ' ', ' ', 'G'],
        ]
        self.game_manual = '1.↑\t2.→\t3.↓\t4.←\t5.exit'
        self.y = 0
        self.x = 0
        self.goal_y = 3
        self.goal_x = 3
        self.width = len(self.game_map[0]) - 1
        self.height = len(self.game_map) - 1

    def run(self):
        while True:
            self.show()  # 画面を表示する
            command = input()  # 入力を受け付ける
            # 終了キーならば終了
            if command == self.EXIT:
                break
            # 移動キーならば、更新処理
            if command in (self.UP, self.DOWN, self.RIGHT, self.LEFT):
                self.update(command)
                # ゴールに到達していれば、終わり!
                if self.y == self.goal_y and self.x == self.goal_x:
                    print('ゴールに到達!')
                    break

    def show(self):
        # 操作説明の表示
        print(self.game_manual)
        # マップの表示
        for line in self.game_map:
            print(''.join(line))

    def update(self, command):
        y, x = self.y, self.x
        if command == self.UP:
            y -= 1
        elif command == self.RIGHT:
            x += 1
        elif command == self.DOWN:
            y += 1
        elif command == self.LEFT:
            x -= 1

        # 画面外でなく、壁('#')でもない場合に移動処理をする
        if 0 <= x <= self.width and 0 <= y <= self.height and self.game_map[y][x] != '#':
            self.game_map[self.y][self.x] = ' '  # 元いた位置に' 'を入れる
            self.game_map[y][x] = 'Y'  # 移動先に'Y'を入れる
            self.y, self.x = y, x  # 現在座標の更新


def main():
    maze = Maze()
    maze.run()  # 迷路ゲーム開始


if __name__ == '__main__':
    main()
